Common GUI widgets
==================
General purpose widgets that have not been specially design for displaying or processing tomography results. 

.. automodule:: tomotok.gui.widgets
    :noindex:
    :members: GraphWindow, MasterControls
